package com.pointrlabs.sample.selection;

import android.content.Context;
import android.content.Intent;
import android.os.Bundle;

import androidx.annotation.NonNull;
import androidx.annotation.Nullable;
import androidx.appcompat.app.AppCompatActivity;
import androidx.recyclerview.widget.RecyclerView;

import com.pointrlabs.core.management.Pointr;
import com.pointrlabs.core.management.models.Building;
import com.pointrlabs.core.management.models.Site;
import com.pointrlabs.core.site.SiteManager;
import com.pointrlabs.sample.R;

import java.util.ArrayList;
import java.util.Collections;

/**
 * Activity to present the venue list to choose from
 */
public class SelectionActivity extends AppCompatActivity implements
        SiteManager.Listener,
        BuildingSelectionAdapter.Listener {

    /**
     * Creates the intent to start this activity
     *
     * @return intent to start {@link SelectionActivity}
     */
    public static Intent newIntent(@NonNull Context context) {
        return new Intent(context, SelectionActivity.class);
    }

    private SiteManager siteManager;

    private final BuildingSelectionAdapter adapter = new BuildingSelectionAdapter(this);

    @Override
    protected void onCreate(@Nullable Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_venue_selection);
        // Before accessing the Pointr Managers make sure that Pointr is started.
        // For this case, we make sure that loading activity launches
        // this activity only when pointr is up and running
        assert Pointr.getPointr() != null;
        siteManager = Pointr.getPointr().getSiteManager();

        final RecyclerView recyclerView = findViewById(R.id.selectionListRecyclerView);
        recyclerView.setAdapter(adapter);

        adapter.submitList(getBuildings());
    }

    @Override
    protected void onStart() {
        super.onStart();
        siteManager.addListener(this);
    }

    @Override
    protected void onStop() {
        super.onStop();
        siteManager.removeListener(this);
    }

    // region [SiteManager.Listener]
    @Override
    public void onSiteManagerDataChanged() {
        adapter.submitList(getBuildings());
    }
    // endregion [VenueFacilityManager.Listener]

    // region [BuildingSelectionAdapter.Listener
    @Override
    public void onBuildingSelected(int siteInternalIdentifier) {
        startActivity(com.pointrlabs.sample.map.MapActivity.newIntent(this, siteInternalIdentifier));
    }

    // endregion [BuildingSelectionAdapter.Listener]

    private ArrayList<Building> getBuildings() {
        ArrayList<Building> buildings = new ArrayList<Building>();
        for(Site site: siteManager.getSites()) {
            buildings.addAll(site.getBuildings());
        }
        return buildings;
    }
}
